@@ -49,7 +49,7 @@ def extra(
         else:
             module.__funcs__ = [func]  # type: ignore
 
-        profiling_name = f"{module}.{func.__name__}"
+        profiling_name = f"{submodule}.{func.__name__}"
         return _gather_metrics(name=profiling_name, func=func)
 
     def wrapper(f: F) -> F:
