@@ -1,3 +1,6 @@
+import base64
+from pathlib import Path
+
 import streamlit as st
 import validators
 
@@ -5,23 +8,28 @@ from .. import extra
 
 
 @extra
-def add_logo(logo_url: str):
+def add_logo(logo_url: str, height: int = 120):
     """Add a logo (from logo_url) on the top of the navigation page of a multipage app.
     Taken from https://discuss.streamlit.io/t/put-logo-and-title-above-on-top-of-page-navigation-in-sidebar-of-multipage-app/28213/6
 
+    The url can either be a url to the image, or a local path to the image.
+
     Args:
-        logo_url (HttpUrl): URL of the logo
+        logo_url (str): URL/local path of the logo
     """
 
-    validators.url(logo_url)
+    if validators.url(logo_url) is True:
+        logo = f"url({logo_url})"
+    else:
+        logo = f"url(data:image/png;base64,{base64.b64encode(Path(logo_url).read_bytes()).decode()})"
 
     st.markdown(
         f"""
         <style>
             [data-testid="stSidebarNav"] {{
-                background-image: url({logo_url});
+                background-image: {logo};
                 background-repeat: no-repeat;
-                padding-top: 80px;
+                padding-top: {height - 40}px;
                 background-position: 20px 20px;
             }}
         </style>
@@ -31,7 +39,10 @@ def add_logo(logo_url: str):
 
 
 def example():
-    add_logo("http://placekitten.com/120/120")
+    if st.checkbox("Use url", value=True):
+        add_logo("http://placekitten.com/120/120")
+    else:
+        add_logo("gallery/kitty.jpeg", height=300)
     st.write("👈 Check out the cat in the nav-bar!")
 
 
